#ifndef _K_PERM_H
#define _K_PERM_H 1

#include <stddef.h> /* For size_t */

unsigned int AInext_k_permutation(unsigned int *ar, size_t n, size_t k);

#endif
